==> kubernetes-model-events-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/events/v1beta1/EventBuilder.java <==
package io.fabric8.kubernetes.api.model.events.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EventBuilder extends EventFluentImpl<EventBuilder> implements VisitableBuilder<Event,EventBuilder>{
  public EventBuilder() {
    this(false);
  }
  public EventBuilder(Boolean validationEnabled) {
    this(new Event(), validationEnabled);
  }
  public EventBuilder(EventFluent<?> fluent) {
    this(fluent, false);
  }
  public EventBuilder(EventFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Event(), validationEnabled);
  }
  public EventBuilder(EventFluent<?> fluent,Event instance) {
    this(fluent, instance, false);
  }
  public EventBuilder(EventFluent<?> fluent,Event instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAction(instance.getAction());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withDeprecatedCount(instance.getDeprecatedCount());
      fluent.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp());
      fluent.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp());
      fluent.withDeprecatedSource(instance.getDeprecatedSource());
      fluent.withEventTime(instance.getEventTime());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withNote(instance.getNote());
      fluent.withReason(instance.getReason());
      fluent.withRegarding(instance.getRegarding());
      fluent.withRelated(instance.getRelated());
      fluent.withReportingController(instance.getReportingController());
      fluent.withReportingInstance(instance.getReportingInstance());
      fluent.withSeries(instance.getSeries());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EventBuilder(Event instance) {
    this(instance,false);
  }
  public EventBuilder(Event instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAction(instance.getAction());
      this.withApiVersion(instance.getApiVersion());
      this.withDeprecatedCount(instance.getDeprecatedCount());
      this.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp());
      this.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp());
      this.withDeprecatedSource(instance.getDeprecatedSource());
      this.withEventTime(instance.getEventTime());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withNote(instance.getNote());
      this.withReason(instance.getReason());
      this.withRegarding(instance.getRegarding());
      this.withRelated(instance.getRelated());
      this.withReportingController(instance.getReportingController());
      this.withReportingInstance(instance.getReportingInstance());
      this.withSeries(instance.getSeries());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EventFluent<?> fluent;
  Boolean validationEnabled;
  public Event build() {
    Event buildable = new Event(fluent.getAction(),fluent.getApiVersion(),fluent.getDeprecatedCount(),fluent.getDeprecatedFirstTimestamp(),fluent.getDeprecatedLastTimestamp(),fluent.getDeprecatedSource(),fluent.getEventTime(),fluent.getKind(),fluent.getMetadata(),fluent.getNote(),fluent.getReason(),fluent.getRegarding(),fluent.getRelated(),fluent.getReportingController(),fluent.getReportingInstance(),fluent.getSeries(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-events-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/events/v1beta1/EventBuilder.java <==
package io.fabric8.kubernetes.api.model.events.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EventBuilder extends EventFluent<EventBuilder> implements VisitableBuilder<Event,EventBuilder>{
  public EventBuilder() {
    this(false);
  }
  public EventBuilder(Boolean validationEnabled) {
    this(new Event(), validationEnabled);
  }
  public EventBuilder(EventFluent<?> fluent) {
    this(fluent, false);
  }
  public EventBuilder(EventFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Event(), validationEnabled);
  }
  public EventBuilder(EventFluent<?> fluent,Event instance) {
    this(fluent, instance, false);
  }
  public EventBuilder(EventFluent<?> fluent,Event instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Event());

    if (instance != null) {
      fluent.withAction(instance.getAction());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withDeprecatedCount(instance.getDeprecatedCount());
      fluent.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp());
      fluent.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp());
      fluent.withDeprecatedSource(instance.getDeprecatedSource());
      fluent.withEventTime(instance.getEventTime());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withNote(instance.getNote());
      fluent.withReason(instance.getReason());
      fluent.withRegarding(instance.getRegarding());
      fluent.withRelated(instance.getRelated());
      fluent.withReportingController(instance.getReportingController());
      fluent.withReportingInstance(instance.getReportingInstance());
      fluent.withSeries(instance.getSeries());
      fluent.withType(instance.getType());
      fluent.withAction(instance.getAction());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withDeprecatedCount(instance.getDeprecatedCount());
      fluent.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp());
      fluent.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp());
      fluent.withDeprecatedSource(instance.getDeprecatedSource());
      fluent.withEventTime(instance.getEventTime());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withNote(instance.getNote());
      fluent.withReason(instance.getReason());
      fluent.withRegarding(instance.getRegarding());
      fluent.withRelated(instance.getRelated());
      fluent.withReportingController(instance.getReportingController());
      fluent.withReportingInstance(instance.getReportingInstance());
      fluent.withSeries(instance.getSeries());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EventBuilder(Event instance) {
    this(instance,false);
  }
  public EventBuilder(Event instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Event());

    if (instance != null) {
      this.withAction(instance.getAction());
      this.withApiVersion(instance.getApiVersion());
      this.withDeprecatedCount(instance.getDeprecatedCount());
      this.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp());
      this.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp());
      this.withDeprecatedSource(instance.getDeprecatedSource());
      this.withEventTime(instance.getEventTime());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withNote(instance.getNote());
      this.withReason(instance.getReason());
      this.withRegarding(instance.getRegarding());
      this.withRelated(instance.getRelated());
      this.withReportingController(instance.getReportingController());
      this.withReportingInstance(instance.getReportingInstance());
      this.withSeries(instance.getSeries());
      this.withType(instance.getType());
      this.withAction(instance.getAction());
      this.withApiVersion(instance.getApiVersion());
      this.withDeprecatedCount(instance.getDeprecatedCount());
      this.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp());
      this.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp());
      this.withDeprecatedSource(instance.getDeprecatedSource());
      this.withEventTime(instance.getEventTime());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withNote(instance.getNote());
      this.withReason(instance.getReason());
      this.withRegarding(instance.getRegarding());
      this.withRelated(instance.getRelated());
      this.withReportingController(instance.getReportingController());
      this.withReportingInstance(instance.getReportingInstance());
      this.withSeries(instance.getSeries());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EventFluent<?> fluent;
  Boolean validationEnabled;
  public Event build() {
    Event buildable = new Event(fluent.getAction(),fluent.getApiVersion(),fluent.getDeprecatedCount(),fluent.getDeprecatedFirstTimestamp(),fluent.getDeprecatedLastTimestamp(),fluent.getDeprecatedSource(),fluent.getEventTime(),fluent.getKind(),fluent.buildMetadata(),fluent.getNote(),fluent.getReason(),fluent.buildRegarding(),fluent.buildRelated(),fluent.getReportingController(),fluent.getReportingInstance(),fluent.buildSeries(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
